Method: Xcode::Configuration.default_properties

Defined in:
lib/xcode/configuration.rb

.default_properties(name) ⇒ Hash

TODO:

remove the name requirement and replace all these configuration settings with the smaller subset. As a lot of these are usually maintained by the project

A large number of these default build settings properties for a configuration are as defined for Xcode 4.2.

Parameters:

  • name (String)

    is used to create the correct prefix header file and info.plist file.

Returns:

  • (Hash)

    properties for a default build configuration



49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/xcode/configuration.rb', line 49

def self.default_properties(name)
  { 'isa' => 'XCBuildConfiguration',
    'buildSettings' => {
      "SDKROOT" => "iphoneos",
      "OTHER_CFLAGS" => "-DNS_BLOCK_ASSERTIONS=1",
      "TARGETED_DEVICE_FAMILY" => "1,2",
      "GCC_C_LANGUAGE_STANDARD" => "gnu99",
      "ALWAYS_SEARCH_USER_PATHS" => "NO",
      "GCC_VERSION" => "com.apple.compilers.llvm.clang.1_0",
      "ARCHS" => "$(ARCHS_STANDARD_32_BIT)",
      "GCC_WARN_ABOUT_MISSING_PROTOTYPES" => "YES",
      "GCC_WARN_ABOUT_RETURN_TYPE" => "YES",
      "CODE_SIGN_IDENTITY[sdk=>iphoneos*]" => "iPhone Developer",
      "GCC_PRECOMPILE_PREFIX_HEADER" => "YES",
      "VALIDATE_PRODUCT" => "YES",
      "IPHONEOS_DEPLOYMENT_TARGET" => "5.0",
      "COPY_PHASE_STRIP" => "YES",
      "GCC_PREFIX_HEADER" => "#{name}/#{name}-Prefix.pch",
      "INFOPLIST_FILE" => "#{name}/#{name}-Info.plist",
      "PRODUCT_NAME" => "$(TARGET_NAME)",
      "WRAPPER_EXTENSION" => "app" },
      "name" => name }
end