Method: Xcode::Project#group
- Defined in:
- lib/xcode/project.rb
#group(name, options = {}, &block) ⇒ Group
Note:
this will attempt to find the paths specified, if it fails to find them it will create one and then continue traversing.
Note:
this path functionality current is only exercised from the project level all groups will treat the path division / as simply a character.
Returns the group specified. If any part of the group does not exist along the path the group is created. Also paths can be specified to make the traversing of the groups easier.
145 146 147 |
# File 'lib/xcode/project.rb', line 145 def group(name, = {},&block) @project.group(name,,&block) end |